@@ -3,13 +3,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.5901';
+our $VERSION = '0.5902';
 
 use warnings;
 use strict;
 
 use parent qw(Graph);
 
+use Carp qw( croak );
 use Readonly;
 Readonly my $WEIGHT => 'weight';
 
@@ -52,7 +53,7 @@ sub populate {
         }
     }
     else {
-        warn "Unknown data type: $data\n";
+        croak "Unknown data type: $data\n";
     }
 }
 
@@ -118,7 +119,7 @@ sub get_weight {
 
 sub get_cost {
     my ($self, $v, $attr) = @_;
-    die 'ERROR: No vertex given to get_cost()' unless defined $v;
+    croak 'ERROR: No vertex given to get_cost()' unless defined $v;
 
     # Default to weight.
     $attr ||= $WEIGHT;
@@ -219,7 +220,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.5901
+version 0.5902
 
 =head1 SYNOPSIS
 
@@ -321,7 +322,9 @@ Return the weight for the vertex or edge.
 
 =head2 get_cost()
 
+  $w = $gw->get_cost($vertex);
   $w = $gw->get_cost($vertex, $attribute);
+  $w = $gw->get_cost(\@edge);
   $w = $gw->get_cost(\@edge, $attribute);
 
 Return the named attribute value for the vertex or edge.
